timerelationtools.timespan_2_stops_when_timespan_1_stops
========================================================

.. autofunction:: abjad.tools.timerelationtools.timespan_2_stops_when_timespan_1_stops.timespan_2_stops_when_timespan_1_stops
   :noindex:
